==> org-lsst-ccs-buses-definition-2.1.0-sources.jar: org/lsst/ccs/bus/data/RaisedAlertSummary.java <==
package org.lsst.ccs.bus.data;

import java.io.Serializable;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import java.util.concurrent.CopyOnWriteArrayList;
import org.lsst.ccs.bus.states.AlertState;

/**
 * A summary of the alerts that have been raised by a Subsystem.
 * This class is used internally by a Subsystem to internally keep a record of
 * the Alerts that have been raised.
 * It is also published on the buses to provide a summary of the subsystem's
 * raised alerts.
 *
 *
 * @author The LSST CCS Team.
 *
 */
public class RaisedAlertSummary implements Serializable {

    /**
     * Change when backward incompatible changes are made.
     */
    private static final long serialVersionUID = -9649721904826248L;

    protected final List<RaisedAlertHistory> raisedAlerts = new CopyOnWriteArrayList<>();

    /**
     * Get a RaisedAlert for a given id.
     * 
     * @param alertId The alert Id
     * @return The corresponding RaisedAlert.
     * 
     */
    public RaisedAlertHistory getRaisedAlert(String alertId) {
        for (RaisedAlertHistory raisedAlert : raisedAlerts) {
            if (raisedAlert.getAlert().getAlertId().equals(alertId)) {
                return raisedAlert;
            }
        }
        return null;
    }

    /**
     * Get the overall AlertState for this RaisedAlarm summary object .
     *
     * This is the highest AlertState among all the RaisedAlerts for the
     * subsystem.
     *
     * @return The highest AlertState.
     */
    public AlertState getAlertState() {
        AlertState base = AlertState.NOMINAL;
        for (RaisedAlertHistory alert : raisedAlerts) {
            if (alert.getHighestAlertState().compareTo(base) > 0) {
                base = alert.getHighestAlertState();
            }
        }
        return base;
    }

    /**
     * Get the set of raised Alerts.
     *
     * @return The Set of RaisedAlertHistories.
     */
    public Set<RaisedAlertHistory> getAllRaisedAlertHistories() {
        return new HashSet<>(raisedAlerts);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("Alarm Summary\n");
        sb.append("Severity : ").append(getAlertState()).append("\n");
        for (RaisedAlertHistory alert : getAllRaisedAlertHistories()) {
            sb.append("Alert: ").append(alert.getAlert().getAlertId()).append(" instances: ").append(alert.getNumberOfInstances()).append(" severity: ").append(alert.getHighestAlertState()).append("\n");
        }
        return sb.toString();
    }

}

==> org-lsst-ccs-buses-definition-2.1.2-sources.jar: org/lsst/ccs/bus/data/RaisedAlertSummary.java <==
package org.lsst.ccs.bus.data;

import java.io.Serializable;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import java.util.concurrent.CopyOnWriteArrayList;
import org.lsst.ccs.bus.states.AlertState;

/**
 * A summary of the alerts that have been raised by a Subsystem.
 * This class is used internally by a Subsystem to internally keep a record of
 * the Alerts that have been raised.
 * It is also published on the buses to provide a summary of the subsystem's
 * raised alerts.
 *
 *
 * @author The LSST CCS Team.
 *
 */
public class RaisedAlertSummary implements Serializable {

    /**
     * Change when backward incompatible changes are made.
     */
    private static final long serialVersionUID = -9649721904826248L;

    protected final List<RaisedAlertHistory> raisedAlerts = new CopyOnWriteArrayList<>();
    // REVIEW: does this need to be CopyOnWriteArrayList ? RaisedAlertHistory is not thread-safe anyway.

    /**
     * Get a RaisedAlert for a given id.
     * 
     * @param alertId The alert Id
     * @return The corresponding RaisedAlert.
     * 
     */
    public RaisedAlertHistory getRaisedAlert(String alertId) {
        for (RaisedAlertHistory raisedAlert : raisedAlerts) {
            if (raisedAlert.getLatestAlert().getAlertId().equals(alertId)) {
                return raisedAlert;
            }
        }
        return null;
    }

    /**
     * Get the overall AlertState for this RaisedAlarm summary object .
     *
     * This is the highest AlertState among all the RaisedAlerts for the
     * subsystem.
     *
     * @return The highest AlertState.
     */
    public AlertState getAlertState() {
        AlertState base = AlertState.NOMINAL;
        for (RaisedAlertHistory alert : raisedAlerts) {
            if (alert.getHighestAlertState().compareTo(base) > 0) {
                base = alert.getHighestAlertState();
            }
        }
        return base;
    }

    /**
     * Get the set of raised Alerts.
     *
     * @return The Set of RaisedAlertHistories.
     */
    public Set<RaisedAlertHistory> getAllRaisedAlertHistories() {
        return new HashSet<>(raisedAlerts);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("Alarm Summary\n");
        sb.append("Severity : ").append(getAlertState()).append("\n");
        for (RaisedAlertHistory alert : getAllRaisedAlertHistories()) {
            sb.append("Alert: ").append(alert.getLatestAlert().getAlertId()).append(" instances: ").append(alert.getNumberOfInstances()).append(" severity: ").append(alert.getHighestAlertState()).append("\n");
        }
        return sb.toString();
    }

}
